@@ -176,7 +176,7 @@ class FeedEntry(object):
 			guid.text = self.__rss_guid
 			guid.attrib['isPermaLink'] = 'false'
 		for cat in self.__rss_category or []:
-			category = etree.SubElement(channel, 'category')
+			category = etree.SubElement(entry, 'category')
 			category.text = cat['value']
 			if cat.get('domain'):
 				category.attrib['domain'] = cat['domain']
@@ -189,9 +189,9 @@ class FeedEntry(object):
 			enclosure.attrib['length'] = self.__rss_enclosure['length']
 			enclosure.attrib['type'] = self.__rss_enclosure['type']
 		if self.__rss_pubDate:
-			pubDate = etree.SubElement(channel, 'pubDate')
+			pubDate = etree.SubElement(entry, 'pubDate')
 			pubDate.text = self.__rss_pubDate.strftime(
-					'%a, %e %b %Y %H:%M:%S %z')
+					'%a, %d %b %Y %H:%M:%S %z')
 
 		if extensions:
 			for ext in self.__extensions.values() or []:
@@ -253,12 +253,12 @@ class FeedEntry(object):
 		:returns: Modification date as datetime.datetime
 		'''
 		if not updated is None:
-			if isinstance(updated, basestr):
+			if isinstance(updated, basestring):
 				updated = dateutil.parser.parse(updated)
-			if not isinstance(updated, datetime.datetime):
-				ValueError('Invalid datetime format')
+			if not isinstance(updated, datetime):
+				raise ValueError('Invalid datetime format')
 			if updated.tzinfo is None:
-				ValueError('Datetime object has no timezone info')
+				raise ValueError('Datetime object has no timezone info')
 			self.__atom_updated = updated
 			self.__rss_lastBuildDate = updated
 
@@ -504,7 +504,7 @@ class FeedEntry(object):
 
 
 	def published(self, published=None):
-		'''Set or get the published value which ontains the time of the initial
+		'''Set or get the published value which contains the time of the initial
 		creation or first availability of the entry.
 
 		The value can either be a string which will automatically be parsed or a
@@ -515,12 +515,12 @@ class FeedEntry(object):
 		:returns: Creation date as datetime.datetime
 		'''
 		if not published is None:
-			if isinstance(published, basestr):
+			if isinstance(published, basestring):
 				published = dateutil.parser.parse(published)
-			if not isinstance(published, datetime.datetime):
-				ValueError('Invalid datetime format')
+			if not isinstance(published, datetime):
+				raise ValueError('Invalid datetime format')
 			if published.tzinfo is None:
-				ValueError('Datetime object has no timezone info')
+				raise ValueError('Datetime object has no timezone info')
 			self.__atom_published = published
 			self.__rss_pubDate = published
 
