@@ -16,7 +16,7 @@ import dateutil.tz
 from feedgen.entry import FeedEntry
 from feedgen.util import ensure_format
 
-_feedgen_version = '0.2.2'
+_feedgen_version = '0.2.3'
 
 class FeedGenerator(object):
 	'''FeedGenerator for generating ATOM and RSS feeds.
@@ -284,14 +284,14 @@ class FeedGenerator(object):
 		if self.__rss_lastBuildDate:
 			lastBuildDate = etree.SubElement(channel, 'lastBuildDate')
 			lastBuildDate.text = self.__rss_lastBuildDate.strftime(
-					'%a, %e %b %Y %H:%M:%S %z')
+					'%a, %d %b %Y %H:%M:%S %z')
 		if self.__rss_managingEditor:
 			managingEditor = etree.SubElement(channel, 'managingEditor')
 			managingEditor.text = self.__rss_managingEditor
 		if self.__rss_pubDate:
 			pubDate = etree.SubElement(channel, 'pubDate')
 			pubDate.text = self.__rss_pubDate.strftime(
-					'%a, %e %b %Y %H:%M:%S %z')
+					'%a, %d %b %Y %H:%M:%S %z')
 		if self.__rss_rating:
 			rating = etree.SubElement(channel, 'rating')
 			rating.text = self.__rss_rating
@@ -395,16 +395,19 @@ class FeedGenerator(object):
 
 		This will set both atom:updated and rss:lastBuildDate.
 
+		Default value
+			If not set, updated has as value the current date and time.
+
 		:param updated: The modification date.
 		:returns: Modification date as datetime.datetime
 		'''
 		if not updated is None:
-			if isinstance(updated, basestr):
+			if isinstance(updated, basestring):
 				updated = dateutil.parser.parse(updated)
 			if not isinstance(updated, datetime.datetime):
-				ValueError('Invalid datetime format')
+				raise ValueError('Invalid datetime format')
 			if updated.tzinfo is None:
-				ValueError('Datetime object has no timezone info')
+				raise ValueError('Datetime object has no timezone info')
 			self.__atom_updated = updated
 			self.__rss_lastBuildDate = updated
 
@@ -421,6 +424,9 @@ class FeedGenerator(object):
 
 		This will set both atom:updated and rss:lastBuildDate.
 
+		Default value
+			If not set, lastBuildDate has as value the current date and time.
+
 		:param lastBuildDate: The modification date.
 		:returns: Modification date as datetime.datetime
 		'''
@@ -433,11 +439,13 @@ class FeedGenerator(object):
 		for RSS.
 
 		This method can be called with:
+
 		- the fields of an author as keyword arguments
 		- the fields of an author as a dictionary
 		- a list of dictionaries containing the author fields
 
 		An author has the following fields:
+
 		- *name* conveys a human-readable name for the person.
 		- *uri* contains a home page for the person.
 		- *email* contains an email address for the person.
@@ -535,11 +543,13 @@ class FeedGenerator(object):
 		'''Get or set categories that the feed belongs to.
 
 		This method can be called with:
+
 		- the fields of a category as keyword arguments
 		- the fields of a category as a dictionary
 		- a list of dictionaries containing the category fields
 
 		A categories has the following fields:
+
 		- *term* identifies the category
 		- *scheme* identifies the categorization scheme via a URI.
 		- *label* provides a human-readable label for display
@@ -807,12 +817,12 @@ class FeedGenerator(object):
 		:returns: Publication date as datetime.datetime
 		'''
 		if not pubDate is None:
-			if isinstance(pubDate, basestr):
+			if isinstance(pubDate, basestring):
 				pubDate = dateutil.parser.parse(pubDate)
 			if not isinstance(pubDate, datetime.datetime):
-				ValueError('Invalid datetime format')
+				raise ValueError('Invalid datetime format')
 			if pubDate.tzinfo is None:
-				ValueError('Datetime object has no timezone info')
+				raise ValueError('Datetime object has no timezone info')
 			self.__rss_pubDate = pubDate
 
 		return self.__rss_pubDate
@@ -843,7 +853,7 @@ class FeedGenerator(object):
 				hours = [hours]
 			for h in hours:
 				if not h in xrange(24):
-					ValueError('Invalid hour %s' % h)
+					raise ValueError('Invalid hour %s' % h)
 			if replace or not self.__rss_skipHours:
 				self.__rss_skipHours = set()
 			self.__rss_skipHours |= set(hours)
@@ -867,7 +877,7 @@ class FeedGenerator(object):
 			for d in days:
 				if not d in ['Monday', 'Tuesday', 'Wednesday', 'Thursday',
 						'Friday', 'Saturday', 'Sunday']:
-					ValueError('Invalid day %s' % h)
+					raise ValueError('Invalid day %s' % h)
 			if replace or not self.__rss_skipDays:
 				self.__rss_skipDays = set()
 			self.__rss_skipDays |= set(days)
